@@ -4,11 +4,6 @@
 #include <lcrq_pvt.h>
 #include <arpa/inet.h>
 #include <assert.h>
-#ifdef HAVE_ENDIAN_H
-#include <endian.h>
-#elif HAVE_SYS_ENDIAN_H
-#include <sys/endian.h>
-#endif
 #include <errno.h>
 #include <gf256.h>
 #include <stdlib.h>
@@ -16,6 +11,18 @@
 #include <sys/param.h>
 #include <time.h>
 
+#ifdef HAVE_ENDIAN_H
+# include <endian.h>
+#elif defined(HAVE_SYS_ENDIAN_H)
+# include <sys/endian.h>
+#elif defined(HAVE_LIBKERN_OSBYTEORDER_H)
+# include <libkern/OSByteOrder.h>
+# define htobe64(x) OSSwapHostToBigInt64(x)
+# define htobe32(x) OSSwapHostToBigInt32(x)
+# define be64toh(x) OSSwapBigToHostInt64(x)
+# define be32toh(x) OSSwapBigToHostInt32(x)
+#endif
+
 #if (defined(HAVE_LIBSODIUM))
 # include <sodium.h>
 #elif (defined(HAVE_GETRANDOM))
@@ -163,7 +170,7 @@ static uint32_t rq_random_esi(uint32_t min)
 #ifdef WORDS_BIGENDIAN
 	a++;
 #endif
-#ifdef HAVE_GETRANDOM
+#if defined(HAVE_GETRANDOM) && defined(HAVE_SYS_RANDOM_H)
 	while ((byt = getrandom(a, len, 0)) != len) {
 #else
 	static int f; /* we'll keep the handle until program exit */
