@@ -11,6 +11,9 @@
 #include <sys/time.h>
 #include <sys/resource.h>
 #include <unistd.h>
+#ifdef HAVE_SYS_RANDOM_H
+# include <sys/random.h>
+#endif
 
 #define DEFAULT_TERM_COLS 80
 #define TESTID_WIDTH 16
@@ -99,6 +102,7 @@ void test_log(char *msg, ...)
 	vsprintf(b, msg, argp);
 	sem_wait(&log_lock);
 	fprintf(stderr, "%s\n", b);
+	fflush(stderr);
 	sem_post(&log_lock);
 	va_end(argp);
 	free(b);
@@ -137,6 +141,7 @@ void test_name(char *str, ...)
 	vsprintf(b, str, argp);
 	test_log("  (%s)", b);
 	printf("%-*s", MSGW, b);
+	fflush(stdout);
 	va_end(argp);
 	free(b);
 }
@@ -204,7 +209,7 @@ void test_rusage()
 void test_randombytes(void *buf, size_t len)
 {
 	ssize_t return_ignored;
-#ifdef HAVE_GETRANDOM
+#if defined(HAVE_GETRANDOM) && defined(HAVE_SYS_RANDOM_H)
 	return_ignored = getrandom(buf, len, 0);
 #else
 	static int f; /* we'll keep the handle until program exit */
